<a id="mypy-boto3-route53-recovery-control-config"></a>

# mypy-boto3-route53-recovery-control-config

[![PyPI - mypy-boto3-route53-recovery-control-config](https://img.shields.io/pypi/v/mypy-boto3-route53-recovery-control-config.svg?color=blue)](https://pypi.org/project/mypy-boto3-route53-recovery-control-config)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-route53-recovery-control-config.svg?color=blue)](https://pypi.org/project/mypy-boto3-route53-recovery-control-config)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-route53-recovery-control-config?color=blue)](https://pypistats.org/packages/mypy-boto3-route53-recovery-control-config)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Route53RecoveryControlConfig 1.19.0](https://boto3.amazonaws.com/v1/documentation/api/1.19.0/reference/services/route53-recovery-control-config.html#Route53RecoveryControlConfig)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.5.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-route53-recovery-control-config docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_control_config/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-route53-recovery-control-config](#mypy-boto3-route53-recovery-control-config)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Route53RecoveryControlConfig` service.

```bash
python -m pip install boto3-stubs[route53-recovery-control-config]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[route53-recovery-control-config]` in your environment:
  `python -m pip install 'boto3-stubs[route53-recovery-control-config]'`

Both type checking and auto-complete should work for
`Route53RecoveryControlConfig` service. No explicit type annotations required,
write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[route53-recovery-control-config]` in your environment:
  `python -m pip install 'boto3-stubs[route53-recovery-control-config]'`

Both type checking and auto-complete should work for
`Route53RecoveryControlConfig` service. No explicit type annotations required,
write your `boto3` code as usual. Auto-complete can be slow on big projects or
if you have a lot of installed `boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[route53-recovery-control-config]` in your environment:
  `python -m pip install 'boto3-stubs[route53-recovery-control-config]'`
- Run `mypy` as usual

Type checking should work for `Route53RecoveryControlConfig` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[route53-recovery-control-config]` in your environment:
  `python -m pip install 'boto3-stubs[route53-recovery-control-config]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Route53RecoveryControlConfig` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`Route53RecoveryControlConfigClient` provides annotations for
`boto3.client("route53-recovery-control-config")`.

```python
import boto3

from mypy_boto3_route53_recovery_control_config import Route53RecoveryControlConfigClient

client: Route53RecoveryControlConfigClient = boto3.client("route53-recovery-control-config")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: Route53RecoveryControlConfigClient = session.client("route53-recovery-control-config")
```

<a id="waiters-annotations"></a>

### Waiters annotations

`mypy_boto3_route53_recovery_control_config.waiter` module contains type
annotations for all waiters.

```python
from mypy_boto3_route53_recovery_control_config import Route53RecoveryControlConfigClient
from mypy_boto3_route53_recovery_control_config.waiter import (
    ClusterCreatedWaiter,
    ClusterDeletedWaiter,
    ControlPanelCreatedWaiter,
    ControlPanelDeletedWaiter,
    RoutingControlCreatedWaiter,
    RoutingControlDeletedWaiter,
)

client: Route53RecoveryControlConfigClient = boto3.client("route53-recovery-control-config")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
cluster_created_waiter: ClusterCreatedWaiter = client.get_waiter("cluster_created")
cluster_deleted_waiter: ClusterDeletedWaiter = client.get_waiter("cluster_deleted")
control_panel_created_waiter: ControlPanelCreatedWaiter = client.get_waiter("control_panel_created")
control_panel_deleted_waiter: ControlPanelDeletedWaiter = client.get_waiter("control_panel_deleted")
routing_control_created_waiter: RoutingControlCreatedWaiter = client.get_waiter("routing_control_created")
routing_control_deleted_waiter: RoutingControlDeletedWaiter = client.get_waiter("routing_control_deleted")
```

<a id="literals"></a>

### Literals

`mypy_boto3_route53_recovery_control_config.literals` module contains literals
extracted from shapes that can be used in user code for type checking.

```python
from mypy_boto3_route53_recovery_control_config.literals import (
    ClusterCreatedWaiterName,
    ClusterDeletedWaiterName,
    ControlPanelCreatedWaiterName,
    ControlPanelDeletedWaiterName,
    RoutingControlCreatedWaiterName,
    RoutingControlDeletedWaiterName,
    RuleTypeType,
    StatusType,
    ServiceName,
    WaiterName,
)

def check_value(value: ClusterCreatedWaiterName) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_route53_recovery_control_config.type_defs` module contains
structures and shapes assembled to typed dictionaries for additional type
checking.

```python
from mypy_boto3_route53_recovery_control_config.type_defs import (
    AssertionRuleTypeDef,
    AssertionRuleUpdateTypeDef,
    ClusterEndpointTypeDef,
    ClusterTypeDef,
    ControlPanelTypeDef,
    CreateClusterRequestRequestTypeDef,
    CreateClusterResponseTypeDef,
    CreateControlPanelRequestRequestTypeDef,
    CreateControlPanelResponseTypeDef,
    CreateRoutingControlRequestRequestTypeDef,
    CreateRoutingControlResponseTypeDef,
    CreateSafetyRuleRequestRequestTypeDef,
    CreateSafetyRuleResponseTypeDef,
    DeleteClusterRequestRequestTypeDef,
    DeleteControlPanelRequestRequestTypeDef,
    DeleteRoutingControlRequestRequestTypeDef,
    DeleteSafetyRuleRequestRequestTypeDef,
    DescribeClusterRequestRequestTypeDef,
    DescribeClusterResponseTypeDef,
    DescribeControlPanelRequestRequestTypeDef,
    DescribeControlPanelResponseTypeDef,
    DescribeRoutingControlRequestRequestTypeDef,
    DescribeRoutingControlResponseTypeDef,
    DescribeSafetyRuleRequestRequestTypeDef,
    DescribeSafetyRuleResponseTypeDef,
    GatingRuleTypeDef,
    GatingRuleUpdateTypeDef,
    ListAssociatedRoute53HealthChecksRequestRequestTypeDef,
    ListAssociatedRoute53HealthChecksResponseTypeDef,
    ListClustersRequestRequestTypeDef,
    ListClustersResponseTypeDef,
    ListControlPanelsRequestRequestTypeDef,
    ListControlPanelsResponseTypeDef,
    ListRoutingControlsRequestRequestTypeDef,
    ListRoutingControlsResponseTypeDef,
    ListSafetyRulesRequestRequestTypeDef,
    ListSafetyRulesResponseTypeDef,
    NewAssertionRuleTypeDef,
    NewGatingRuleTypeDef,
    ResponseMetadataTypeDef,
    RoutingControlTypeDef,
    RuleConfigTypeDef,
    RuleTypeDef,
    UpdateControlPanelRequestRequestTypeDef,
    UpdateControlPanelResponseTypeDef,
    UpdateRoutingControlRequestRequestTypeDef,
    UpdateRoutingControlResponseTypeDef,
    UpdateSafetyRuleRequestRequestTypeDef,
    UpdateSafetyRuleResponseTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AssertionRuleTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-route53-recovery-control-config` version is the same as related
`boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-route53-recovery-control-config docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_control_config/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
